/**
 * This software is provided under the terms of the Minecraft Forge Public 
 * License v1.0.
 */

package net.minecraft.src.forge;

import net.minecraft.src.DamageSource;
import net.minecraft.src.EntityLiving;
import net.minecraft.src.EntityPlayer;
import net.minecraft.src.ItemArmor;
import net.minecraft.src.ItemStack;

/**
 * This interface is to be implemented by ItemArmor classes. It will allow to
 * modify computation of damage and health loss. Computation will be called
 * before the actual armor computation, which can then be cancelled.
 *
 * @see ItemArmor
 */
public interface ISpecialArmor 
{
    /** 
     * Retrieves the modifiers to be used when calculating armor damage.
     * Mods should return a new instance every time as the return values 
     * will be manipulated by the damage function.
     * 
     * Armor will higher priority will have damage applied to them before
     * lower priority ones. If there are multiple pieces of armor with the
     * same priority, damage will be distributed between them based on there
     * absorption ratio.
     *
     * @param entity The entity wearing the armor.
     * @param armor The ItemStack of the armor item itself. 
     * @param source The source of the damage, which can be used to alter armor
     *     properties based on the type or source of damage.
     * @param damage The total damage being applied to the entity
     * @param slot The armor slot the item is in. 
     *
     */
	public ArmorProperties getProperties(EntityLiving player, ItemStack armor, DamageSource source, double damage, int slot);
	
	/**
     * Get the displayed effective armor.
     * 
     * @param player The player wearing the armor.
     * @param armor The ItemStack of the armor item itself.  
     * @param slot The armor slot the item is in.
     * @return The number of armor points for display, 2 per shield.
     */
	public abstract int getArmorDisplay(EntityPlayer player, ItemStack armor, int slot);

	/**
	 * Applies damage to the ItemStack. The mod is responsible for reducing the
	 * item durability and stack size. If the stack is depleted it will be cleaned 
	 * up automatically.
	 * 
	 * @param entity The entity wearing the armor
     * @param armor The ItemStack of the armor item itself.
     * @param source The source of the damage, which can be used to alter armor
     *     properties based on the type or source of damage.
	 * @param damage The amount of damage being applied to the armor
     * @param slot The armor slot the item is in.
	 */
    public abstract void damageArmor(EntityLiving entity, ItemStack stack, DamageSource source, int damage, int slot);
}
